package metier;
import java.util.Objects;
import javax.swing.Icon;
import javax.swing.JOptionPane;
import static javax.swing.JOptionPane.WARNING_MESSAGE;

/**
 * Classe Guerrier, hérite de la classe Personnage
 * @author Dominique_2
 * @version 20170115
 */
public class Guerrier extends Personnage{
    // Variable membre
    private String arme;
    
    /**
     * Valorisation des variables membres
     * @param nom       nom du guerrier
     * @param img       nom de l'image représentant le guerrier
     * @param energie   valeur énergétique du guerrier
     * @param dureeVie  durée de vie du guerrier
     * @param arme      armu du guerrier
     */
    public Guerrier(String nom, String img, int energie, int dureeVie, String arme) {
        super(nom, img, energie, dureeVie);
        this.arme = arme;
    }
    /**
     * Permet d'obtenir les valeurs des attributs de l'objet courant
     * @return liste des attributs avec leurs valeurs
     */
    @Override
    public String toString() {
        return super.toString() + "\tArme=" + arme;
    }
    
    /**
     *
     * @return
     */
    @Override
    public int hashCode() {
        int hash = 7;
        hash = super.hashCode() + (13 * hash + Objects.hashCode(this.arme));
        return hash;
    }
    /**
     * Comparaison de l'objet courant avec l'objet passé en paramètre
     * @param obj objet à comparer avec l'objet courant
     * @return true : les 2 objets sont identiques, false sinon
     */
    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final Guerrier other = (Guerrier) obj;
        if (!Objects.equals(this.arme, other.arme)) {
            return false;
        }
        if(!super.equals(obj)){
            return false;
        }
        return true;
    }
    
    /**
     * Get the value of arme
     *
     * @return the value of arme
     */
    public String getArme() {
        return arme;
    }
    
    /**
     * Set the value of arme
     *
     * @param arme new value of arme
     */
    public void setArme(String arme) {
        this.arme = arme;
    }
    
    /**
     *
     * @param unPerso
     * @return
     */
    public String saluer(Personnage unPerso) {
        String titre = this.getNom() + " salue " + unPerso.getNom();
        String message = "Bonjour " + unPerso.getNom() + ", sauve-toi vite avant que je ne te frappe avec mon arme redoutable !";
        JOptionPane.showMessageDialog(null, message, titre, JOptionPane.INFORMATION_MESSAGE);
        return message;
    }
    
    /**
     *
     * @param unPerso
     * @return
     */
    @Override
    public String rencontrer(Personnage unPerso) {
        String titre = this.getNom() + " rencontre " + unPerso.getNom() + ": dfi ds";
        String message = "Es-tu prt  me combattre " + unPerso.getNom() + "?";
        JOptionPane.showMessageDialog(null, message, titre, JOptionPane.INFORMATION_MESSAGE);
        Icon img = new javax.swing.ImageIcon(getClass().getResource("/img/des.jpg"));
        JOptionPane.showMessageDialog( null, message, titre, WARNING_MESSAGE, img);
        
        int scoreAttaquant = Jeu.genererNbAleatoire(1, 6);
        int scoreAttaque = Jeu.genererNbAleatoire(1, 6);
        
        if (scoreAttaquant == scoreAttaque) {
            message = "Egalit ! Vous avez tous les deux lanc " + scoreAttaquant + ". Rejoue vite !";
            JOptionPane.showMessageDialog(null, message, titre, JOptionPane.WARNING_MESSAGE);
        } else {
            String gagnant = scoreAttaquant > scoreAttaque ? this.getNom() : unPerso.getNom();
            int degats = Math.abs(scoreAttaquant - scoreAttaque); 
            
            if (gagnant.equals(this.getNom())) {
                this.setEnergie(this.getEnergie() + degats);
                this.setDureeVie(this.getDureeVie() + degats);
                message = this.getNom() + " a gagn ! Il inflige " + degats + " points de dommage. " +
                        "Energie: " + this.getEnergie() + ", Dure de vie: " + this.getDureeVie();
            } else {
                unPerso.setEnergie(unPerso.getEnergie() + degats);
                unPerso.setDureeVie(unPerso.getDureeVie() + degats);
                message = unPerso.getNom() + " a gagn ! Il inflige " + degats + " points de dommage. " +
                        "Energie: " + unPerso.getEnergie() + ", Dure de vie: " + unPerso.getDureeVie();
            }
            
            JOptionPane.showMessageDialog(null, message, titre, JOptionPane.INFORMATION_MESSAGE);
        }
        return message;
    }
}    
